@@ -41,7 +41,7 @@ pub fn publish(
         github_api::get_latest_commit_sha(&gh_token, &owner, &name, branch.as_ref(), None)?;
     let mut trs_response = trs::response::TrsResponse::new(&owner, &name)?;
     for config in configs {
-        trs_response.add(&owner, &name, &config, verified)?;
+        trs_response.add(&owner, &name, config, verified)?;
     }
     let trs_contents = trs_response.generate_contents()?;
     let new_tree_sha =
@@ -78,7 +78,7 @@ pub fn publish(
     );
     info!("Please wait for GitHub Pages to be built and published (https://github.com/{}/{}/actions/workflows/pages/pages-build-deployment).", &owner, &name);
     info!(
-        "You can get TRS response like:\n    curl -L https://{}.github.io/{}/tools",
+        "You can get TRS response as:\n    curl -L https://{}.github.io/{}/tools",
         &owner, &name
     );
 
