@@ -462,11 +462,12 @@ pub fn create_empty_branch(
     let mut empty_contents: HashMap<PathBuf, String> = HashMap::new();
 
     let readme_content = r#"
-# TRS responses generated by gh-trs
+# GA4GH Tool Registry Service generated by gh-trs or yevis
 
 ## Docs
 
 - [GitHub - suecharo/gh-trs](https://github.com/suecharo/gh-trs)
+- [GitHub - ddbj/yevis-cli](https://github.com/ddbj/yevis-cli)
 - [GA4GH - Tool Registry Service API](https://www.ga4gh.org/news/tool-registry-service-api-enabling-an-interoperable-library-of-genomics-analysis-tools/)
 - [GitHub - ga4gh/tool-registry-service-schemas](https://github.com/ga4gh/tool-registry-service-schemas)
 "#.to_string();
